@@ -3,7 +3,6 @@ __author__ = 'Bohdan Mushkevych'
 from datetime import datetime
 from logging import ERROR, WARNING, INFO
 
-from synergy.db.error import DuplicateKeyError
 from synergy.db.model import job, unit_of_work
 from synergy.db.manager import ds_manager
 from synergy.conf.process_context import ProcessContext
@@ -14,8 +13,8 @@ from synergy.scheduler.abstract_pipeline import AbstractPipeline
 
 
 class ContinuousPipeline(AbstractPipeline):
-    """ Continuous State Machine re-run process for timeperiod A until A+1, and the transfers the timeperiod to
-     STATE_FINAL_RUN """
+    """ Continuous State Machine re-run process for timeperiod A until A+1,
+        then transfers the timeperiod A to STATE_FINAL_RUN """
 
     def __init__(self, logger, timetable):
         super(ContinuousPipeline, self).__init__(logger, timetable, name=PIPELINE_CONTINUOUS)
@@ -24,8 +23,19 @@ class ContinuousPipeline(AbstractPipeline):
     def __del__(self):
         super(ContinuousPipeline, self).__del__()
 
+    def shallow_state_update(self, uow):
+        tree = self.timetable.get_tree(uow.process_name)
+        node = tree.get_node_by_process(uow.process_name, uow.timeperiod)
+        job_record = node.job_record
+
+        if job_record.state != job.STATE_FINAL_RUN:
+            self.logger.info('Can not perform shallow status update for %s in timeperiod %s '
+                             'since the job state is not STATE_FINAL_RUN' % (uow.process_name, uow.timeperiod))
+            return
+        self._process_state_final_run(uow.process_name, job_record)
+
     @with_reconnect
-    def update_scope_of_processing(self, process_name, uow, start_timeperiod, end_timeperiod, job_record):
+    def update_scope_of_processing(self, process_name, uow, start_timeperiod, end_timeperiod):
         """method reads collection and refine slice upper bound for processing"""
         source_collection_name = uow.source
         last_object_id = self.ds.lowest_primary_key(source_collection_name, start_timeperiod, end_timeperiod)
@@ -33,9 +43,9 @@ class ContinuousPipeline(AbstractPipeline):
         self.uow_dao.update(uow)
 
         msg = 'Updated range to process for %s in timeperiod %s for collection %s: [%s : %s]' \
-              % (process_name, job_record.timeperiod, source_collection_name,
+              % (process_name, start_timeperiod, source_collection_name,
                  uow.start_id, str(last_object_id))
-        self._log_message(INFO, process_name, job_record, msg)
+        self._log_message(INFO, process_name, start_timeperiod, msg)
 
     def _compute_and_transfer_to_progress(self, process_name, start_timeperiod, end_timeperiod, job_record):
         """ method computes new unit_of_work for job record in STATE_IN_PROGRESS
@@ -45,59 +55,28 @@ class ContinuousPipeline(AbstractPipeline):
         -- in case unit_of_work can be located - we update job record and proceed normally
         -- in case unit_of_work can not be located (what is equal to fatal data corruption) - we log exception and
         ask/expect manual intervention to resolve the corruption"""
-        try:
-            source_collection_name = ProcessContext.get_source(process_name)
-            start_id = self.ds.highest_primary_key(source_collection_name, start_timeperiod, end_timeperiod)
-            end_id = self.ds.lowest_primary_key(source_collection_name, start_timeperiod, end_timeperiod)
-            uow = self.insert_uow(process_name,
-                                  start_timeperiod,
-                                  end_timeperiod,
-                                  start_id,
-                                  end_id,
-                                  job_record)
-        except DuplicateKeyError as e:
-            uow = self.uow_dao.recover_from_duplicatekeyerror(e)
-            msg = 'No new data to process by %s in timeperiod %s, because of: %r' \
-                  % (process_name, job_record.timeperiod, e)
-            self._log_message(WARNING, process_name, job_record, msg)
-
-        if uow is not None:
-            # publish the created/caught up unit_of_work
-            self.publish_uow(job_record, uow)
-
-            self.timetable.update_job_record(process_name, job_record, uow, job.STATE_IN_PROGRESS)
-        else:
-            msg = 'MANUAL INTERVENTION REQUIRED! Unable to locate unit_of_work for %s in %s' \
-                  % (process_name, job_record.timeperiod)
-            self._log_message(WARNING, process_name, job_record, msg)
+        source_collection_name = ProcessContext.get_source(process_name)
+        start_id = self.ds.highest_primary_key(source_collection_name, start_timeperiod, end_timeperiod)
+        end_id = self.ds.lowest_primary_key(source_collection_name, start_timeperiod, end_timeperiod)
+        uow, is_duplicate = self.insert_and_publish_uow(process_name,
+                                                        start_timeperiod,
+                                                        end_timeperiod,
+                                                        start_id,
+                                                        end_id)
+        self.timetable.update_job_record(process_name, job_record, uow, job.STATE_IN_PROGRESS)
 
     def _compute_and_transfer_to_final_run(self, process_name, start_timeperiod, end_timeperiod, job_record):
         """ method computes new unit_of_work and transfers the job to STATE_FINAL_RUN
         it also shares _fuzzy_ DuplicateKeyError logic from _compute_and_transfer_to_progress method"""
-        transfer_to_final = False
-        try:
-            source_collection_name = ProcessContext.get_source(process_name)
-            start_id = self.ds.highest_primary_key(source_collection_name, start_timeperiod, end_timeperiod)
-            end_id = self.ds.lowest_primary_key(source_collection_name, start_timeperiod, end_timeperiod)
-            uow = self.insert_uow(process_name,
-                                  start_timeperiod,
-                                  end_timeperiod,
-                                  start_id,
-                                  end_id,
-                                  job_record)
-        except DuplicateKeyError as e:
-            transfer_to_final = True
-            uow = self.uow_dao.recover_from_duplicatekeyerror(e)
-
-        if uow is not None:
-            # publish the created/caught up unit_of_work
-            self.publish_uow(job_record, uow)
-
-            self.timetable.update_job_record(process_name, job_record, uow, job.STATE_FINAL_RUN)
-        else:
-            msg = 'MANUAL INTERVENTION REQUIRED! Unable to locate unit_of_work for %s in %s' \
-                  % (process_name, job_record.timeperiod)
-            self._log_message(WARNING, process_name, job_record, msg)
+        source_collection_name = ProcessContext.get_source(process_name)
+        start_id = self.ds.highest_primary_key(source_collection_name, start_timeperiod, end_timeperiod)
+        end_id = self.ds.lowest_primary_key(source_collection_name, start_timeperiod, end_timeperiod)
+        uow, transfer_to_final = self.insert_and_publish_uow(process_name,
+                                                             start_timeperiod,
+                                                             end_timeperiod,
+                                                             start_id,
+                                                             end_id)
+        self.timetable.update_job_record(process_name, job_record, uow, job.STATE_FINAL_RUN)
 
         if transfer_to_final:
             self._process_state_final_run(process_name, job_record)
@@ -119,7 +98,7 @@ class ContinuousPipeline(AbstractPipeline):
         if start_timeperiod == actual_timeperiod or can_finalize_job_record is False:
             if uow.state in [unit_of_work.STATE_INVALID, unit_of_work.STATE_REQUESTED]:
                 # current uow has not been processed yet. update it
-                self.update_scope_of_processing(process_name, uow, start_timeperiod, end_timeperiod, job_record)
+                self.update_scope_of_processing(process_name, uow, start_timeperiod, end_timeperiod)
             else:
                 # cls.STATE_IN_PROGRESS, cls.STATE_PROCESSED, cls.STATE_CANCELED
                 # create new uow to cover new inserts
@@ -132,34 +111,30 @@ class ContinuousPipeline(AbstractPipeline):
         else:
             msg = 'job record %s has timeperiod from future %s vs current time %s' \
                   % (job_record.db_id, start_timeperiod, actual_timeperiod)
-            self._log_message(ERROR, process_name, job_record, msg)
+            self._log_message(ERROR, process_name, job_record.timeperiod, msg)
 
     def _process_state_final_run(self, process_name, job_record):
         """method takes care of processing job records in STATE_FINAL_RUN state"""
         uow = self.uow_dao.get_one(job_record.related_unit_of_work)
-
         if uow.state == unit_of_work.STATE_PROCESSED:
             self.timetable.update_job_record(process_name, job_record, uow, job.STATE_PROCESSED)
-            timetable_tree = self.timetable.get_tree(process_name)
-            timetable_tree.build_tree()
-            msg = 'Transferred job record %s in timeperiod %s to STATE_PROCESSED for %s' \
-                  % (job_record.db_id, job_record.timeperiod, process_name)
         elif uow.state == unit_of_work.STATE_CANCELED:
             self.timetable.update_job_record(process_name, job_record, uow, job.STATE_SKIPPED)
-            msg = 'Transferred job record %s in timeperiod %s to STATE_SKIPPED for %s' \
-                  % (job_record.db_id, job_record.timeperiod, process_name)
         else:
             msg = 'Suppressed creating uow for %s in timeperiod %s; job record is in %s; uow is in %s' \
                   % (process_name, job_record.timeperiod, job_record.state, uow.state)
-        self._log_message(INFO, process_name, job_record, msg)
+            self._log_message(INFO, process_name, job_record.timeperiod, msg)
+
+        timetable_tree = self.timetable.get_tree(process_name)
+        timetable_tree.build_tree()
 
     def _process_state_skipped(self, process_name, job_record):
         """method takes care of processing job records in STATE_SKIPPED state"""
         msg = 'Skipping job record %s in timeperiod %s. Apparently its most current timeperiod as of %s UTC' \
               % (job_record.db_id, job_record.timeperiod, str(datetime.utcnow()))
-        self._log_message(WARNING, process_name, job_record, msg)
+        self._log_message(WARNING, process_name, job_record.timeperiod, msg)
 
     def _process_state_processed(self, process_name, job_record):
         """method takes care of processing job records in STATE_PROCESSED state"""
         msg = 'Unexpected state %s of job record %s' % (job_record.state, job_record.db_id)
-        self._log_message(ERROR, process_name, job_record, msg)
+        self._log_message(ERROR, process_name, job_record.timeperiod, msg)
