@@ -15,7 +15,7 @@ from synergy.db.dao.scheduler_freerun_entry_dao import SchedulerFreerunEntryDao
 from synergy.system import time_helper
 from synergy.system.decorator import with_reconnect, thread_safe
 from synergy.system.synergy_process import SynergyProcess
-# from synergy.scheduler.status_bus_listener import StatusBusListener
+from synergy.scheduler.status_bus_listener import StatusBusListener
 from synergy.scheduler.scheduler_constants import *
 from synergy.scheduler.continuous_pipeline import ContinuousPipeline
 from synergy.scheduler.dicrete_pipeline import DiscretePipeline
@@ -53,12 +53,9 @@ class Scheduler(SynergyProcess):
             handler.deactivate(update_persistent=False)
         self.freerun_handlers.clear()
 
-        super(Scheduler, self).__del__()
+        self.publishers.close()
 
-    def _log_message(self, level, process_name, job_record, msg):
-        """ method performs logging into log file, Tree node and the Job instance"""
-        self.timetable.add_log_entry(process_name, job_record, datetime.utcnow(), msg)
-        self.logger.log(level, msg)
+        super(Scheduler, self).__del__()
 
     def _construct_pipelines(self):
         """ :return: dict in format <state_machine_common_name: instance_of_the_state_machine> """
@@ -145,8 +142,8 @@ class Scheduler(SynergyProcess):
             self.logger.warn('DB Lookup: %s' % str(e))
 
         # Scheduler is initialized and running. Status Bus Listener can be safely started
-        # self.bus_listener = StatusBusListener(self)
-        # self.bus_listener.start()
+        self.bus_listener = StatusBusListener(self)
+        self.bus_listener.start()
 
         # All Scheduler components are initialized and running. Management Extension (MX) can be safely started
         self.mx = MX(self)
