@@ -129,7 +129,7 @@ class Timetable(object):
 
         tree_node.job_record.number_of_failures = 0
         self.job_dao.update(tree_node.job_record)
-        self.logger.warning(msg)
+        self.logger.warn(msg)
         tree_node.add_log_entry([datetime.utcnow().strftime('%Y-%m-%d %H:%M:%S'), msg])
 
     @thread_safe
@@ -170,7 +170,7 @@ class Timetable(object):
                      tree_node.job_record.state)
 
         self.job_dao.update(tree_node.job_record)
-        self.logger.warning(msg)
+        self.logger.warn(msg)
         tree_node.add_log_entry([datetime.utcnow().strftime('%Y-%m-%d %H:%M:%S'), msg])
 
         if tree_node.process_name in self.reprocess \
@@ -216,10 +216,10 @@ class Timetable(object):
                     unsupported_records[document.process_name] = unsupported_records.get(document.process_name, 0) + 1
 
             for name, counter in unsupported_records.items():
-                self.logger.warning('Skipping %r Job records for %s as no tree is handling it.' % (counter, name))
+                self.logger.warn('Skipping %r Job records for %s as no tree is handling it.' % (counter, name))
 
         except LookupError:
-            self.logger.warning('No Job Records in %s.' % str(collection_name))
+            self.logger.warn('No Job Records in %s.' % str(collection_name))
 
     @thread_safe
     def load_tree(self):
@@ -271,8 +271,11 @@ class Timetable(object):
 
         tree = self.get_tree(process_name)
         tree.update_node_by_process(process_name, job_record)
-        self.logger.info('Updated job record %s in timeperiod %s for %s as %s'
-                         % (job_record.db_id, job_record.timeperiod, process_name, new_state))
+
+        msg = 'Transferred job %s for %s in timeperiod %s to new state %s' \
+              % (job_record.db_id, job_record.timeperiod, process_name, new_state)
+        self.logger.info(msg)
+        self.add_log_entry(process_name, job_record.timeperiod, msg)
 
     @thread_safe
     def failed_on_processing_job_record(self, process_name, timeperiod):
@@ -311,8 +314,8 @@ class Timetable(object):
         return node.can_finalize_job_record()
 
     @thread_safe
-    def add_log_entry(self, process_name, job_record, msg_dt, msg):
+    def add_log_entry(self, process_name, timeperiod, msg):
         """ adds a log entry to the tree node. log entries has no persistence """
         tree = self.get_tree(process_name)
-        node = tree.get_node_by_process(process_name, job_record.timeperiod)
-        node.add_log_entry([msg_dt.strftime('%Y-%m-%d %H:%M:%S'), msg])
+        node = tree.get_node_by_process(process_name, timeperiod)
+        node.add_log_entry([datetime.utcnow().strftime('%Y-%m-%d %H:%M:%S'), msg])
